@@ -3,9 +3,9 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
  'AR': 'ar',
  'ARFLAGS': 'rc',
- 'ASDLGEN': '/usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9/Parser/asdl_c.py',
- 'ASDLGEN_FILES': '/usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9/Parser/asdl.py /usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9/Parser/asdl_c.py',
- 'AST_ASDL': '/usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9/Parser/Python.asdl',
+ 'ASDLGEN': '/usr/src/ports/python/python-2.7.10-1.x86_64/src/Python-2.7.10/Parser/asdl_c.py',
+ 'ASDLGEN_FILES': '/usr/src/ports/python/python-2.7.10-1.x86_64/src/Python-2.7.10/Parser/asdl.py /usr/src/ports/python/python-2.7.10-1.x86_64/src/Python-2.7.10/Parser/asdl_c.py',
+ 'AST_ASDL': '/usr/src/ports/python/python-2.7.10-1.x86_64/src/Python-2.7.10/Parser/Python.asdl',
  'AST_C': 'Python/Python-ast.c',
  'AST_C_DIR': 'Python',
  'AST_H': 'Include/Python-ast.h',
@@ -22,14 +22,14 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'BUILDPYTHON': 'python.exe',
  'CC': 'gcc',
  'CCSHARED': '',
- 'CFLAGS': '-fno-strict-aliasing -ggdb -O2 -pipe -Wimplicit-function-declaration -fdebug-prefix-map=/usr/src/ports/python/python-2.7.9-1.x86_64/build=/usr/src/debug/python-2.7.9-1 -fdebug-prefix-map=/usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9=/usr/src/debug/python-2.7.9-1 -DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes',
+ 'CFLAGS': '-fno-strict-aliasing -ggdb -O2 -pipe -Wimplicit-function-declaration -fdebug-prefix-map=/usr/src/ports/python/python-2.7.10-1.x86_64/build=/usr/src/debug/python-2.7.10-1 -fdebug-prefix-map=/usr/src/ports/python/python-2.7.10-1.x86_64/src/Python-2.7.10=/usr/src/debug/python-2.7.10-1 -DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes',
  'CFLAGSFORSHARED': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
- 'CONFIG_ARGS': "'--srcdir=/usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9' '--prefix=/usr' '--exec-prefix=/usr' '--localstatedir=/var' '--sysconfdir=/etc' '--docdir=/usr/share/doc/python' '--htmldir=/usr/share/doc/python/html' '-C' '--enable-shared' '--enable-ipv6' '--with-dbmliborder=gdbm' '--with-libc=' '--with-libm=' '--with-system-ffi' '--with-system-expat' 'ac_cv_func_bind_textdomain_codeset=yes' 'CC=gcc' 'CFLAGS=-ggdb -O2 -pipe -Wimplicit-function-declaration -fdebug-prefix-map=/usr/src/ports/python/python-2.7.9-1.x86_64/build=/usr/src/debug/python-2.7.9-1 -fdebug-prefix-map=/usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9=/usr/src/debug/python-2.7.9-1' 'LDFLAGS= -L.' 'LIBS=' 'CPPFLAGS= -I/usr/include/ncursesw'",
+ 'CONFIG_ARGS': "'--srcdir=/usr/src/ports/python/python-2.7.10-1.x86_64/src/Python-2.7.10' '--prefix=/usr' '--exec-prefix=/usr' '--localstatedir=/var' '--sysconfdir=/etc' '--docdir=/usr/share/doc/python' '--htmldir=/usr/share/doc/python/html' '-C' '--enable-shared' '--enable-ipv6' '--with-dbmliborder=gdbm' '--with-libc=' '--with-libm=' '--with-system-ffi' '--with-system-expat' 'ac_cv_func_bind_textdomain_codeset=yes' 'CC=gcc' 'CFLAGS=-ggdb -O2 -pipe -Wimplicit-function-declaration -fdebug-prefix-map=/usr/src/ports/python/python-2.7.10-1.x86_64/build=/usr/src/debug/python-2.7.10-1 -fdebug-prefix-map=/usr/src/ports/python/python-2.7.10-1.x86_64/src/Python-2.7.10=/usr/src/debug/python-2.7.10-1' 'LDFLAGS= -L.' 'LIBS=' 'CPPFLAGS='",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python2.7',
  'COREPYTHONPATH': ':plat-cygwin:lib-tk:lib-old',
- 'CPPFLAGS': '-I. -IInclude -I/usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9/Include  -I/usr/include/ncursesw',
+ 'CPPFLAGS': '-I. -IInclude -I/usr/src/ports/python/python-2.7.10-1.x86_64/src/Python-2.7.10/Include',
  'CXX': 'g++',
  'C_THREADS': 0,
  'DESTDIRS': '/usr /usr/lib /usr/lib/python2.7 /usr/lib/python2.7/lib-dynload',
@@ -62,7 +62,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'GNULD': 'yes',
  'GRAMMAR_C': 'Python/graminit.c',
  'GRAMMAR_H': 'Include/graminit.h',
- 'GRAMMAR_INPUT': '/usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9/Grammar/Grammar',
+ 'GRAMMAR_INPUT': '/usr/src/ports/python/python-2.7.10-1.x86_64/src/Python-2.7.10/Grammar/Grammar',
  'HAVE_ACOSH': 1,
  'HAVE_ADDRINFO': 1,
  'HAVE_ALARM': 1,
@@ -139,6 +139,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_GETADDRINFO': 1,
  'HAVE_GETCWD': 1,
  'HAVE_GETC_UNLOCKED': 1,
+ 'HAVE_GETENTROPY': 0,
  'HAVE_GETGROUPS': 1,
  'HAVE_GETHOSTBYNAME': 1,
  'HAVE_GETHOSTBYNAME_R': 0,
@@ -226,6 +227,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_PTHREAD_SIGMASK': 1,
  'HAVE_PTY_H': 1,
  'HAVE_PUTENV': 1,
+ 'HAVE_RAND_EGD': 1,
  'HAVE_READLINK': 1,
  'HAVE_REALPATH': 1,
  'HAVE_RL_CALLBACK': 1,
@@ -348,9 +350,9 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_WORKING_TZSET': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
- 'HGBRANCH': 'hg id -b /usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9',
- 'HGTAG': 'hg id -t /usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9',
- 'HGVERSION': 'hg id -i /usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9',
+ 'HGBRANCH': 'hg id -b /usr/src/ports/python/python-2.7.10-1.x86_64/src/Python-2.7.10',
+ 'HGTAG': 'hg id -t /usr/src/ports/python/python-2.7.10-1.x86_64/src/Python-2.7.10',
+ 'HGVERSION': 'hg id -i /usr/src/ports/python/python-2.7.10-1.x86_64/src/Python-2.7.10',
  'HOST_GNU_TYPE': 'x86_64-unknown-cygwin',
  'HURD_C_THREADS': 0,
  'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python2.7 /usr/include/python2.7',
@@ -396,7 +398,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'MAINCC': 'gcc',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
- 'MAKESETUP': '/usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9/Modules/makesetup',
+ 'MAKESETUP': '/usr/src/ports/python/python-2.7.10-1.x86_64/src/Python-2.7.10/Modules/makesetup',
  'MANDIR': '/usr/share/man',
  'MEMTESTOPTS': '-l -x test_subprocess test_io test_lib2to3 \\ -x test_dl test___all__ test_fork1 \\',
  'MKDIR_P': '/usr/bin/mkdir -p',
@@ -427,7 +429,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'PLATMACPATH': ':plat-mac:plat-mac/lib-scriptpackages',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
- 'PROFILE_TASK': '/usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9/Tools/pybench/pybench.py -n 2 --with-gc --with-syscheck',
+ 'PROFILE_TASK': '/usr/src/ports/python/python-2.7.10-1.x86_64/src/Python-2.7.10/Tools/pybench/pybench.py -n 2 --with-gc --with-syscheck',
  'PSRCS': '\\',
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 0,
  'PURIFY': '',
@@ -441,7 +443,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'PYTHON_FOR_BUILD': './python.exe -E',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
- 'PY_CFLAGS': '-fno-strict-aliasing -ggdb -O2 -pipe -Wimplicit-function-declaration -fdebug-prefix-map=/usr/src/ports/python/python-2.7.9-1.x86_64/build=/usr/src/debug/python-2.7.9-1 -fdebug-prefix-map=/usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9=/usr/src/debug/python-2.7.9-1 -DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes -I. -IInclude -I/usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9/Include  -I/usr/include/ncursesw  -DPy_BUILD_CORE',
+ 'PY_CFLAGS': '-fno-strict-aliasing -ggdb -O2 -pipe -Wimplicit-function-declaration -fdebug-prefix-map=/usr/src/ports/python/python-2.7.10-1.x86_64/build=/usr/src/debug/python-2.7.10-1 -fdebug-prefix-map=/usr/src/ports/python/python-2.7.10-1.x86_64/src/Python-2.7.10=/usr/src/debug/python-2.7.10-1 -DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes -I. -IInclude -I/usr/src/ports/python/python-2.7.10-1.x86_64/src/Python-2.7.10/Include  -DPy_BUILD_CORE',
  'PY_FORMAT_LONG_LONG': '"ll"',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_UNICODE_TYPE': 'wchar_t',
@@ -482,13 +484,13 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'SIZEOF__BOOL': 1,
  'SO': '.dll',
  'SRCDIRS': 'Parser Grammar Objects Python Modules Mac',
- 'SRC_GDB_HOOKS': '/usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9/Tools/gdb/libpython.py',
+ 'SRC_GDB_HOOKS': '/usr/src/ports/python/python-2.7.10-1.x86_64/src/Python-2.7.10/Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
  'STRINGLIB_HEADERS': '\\',
  'SUBDIRS': '',
  'SUBDIRSTOO': 'Include Lib Misc Demo',
- 'SVNVERSION': 'svnversion /usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9',
+ 'SVNVERSION': 'svnversion /usr/src/ports/python/python-2.7.10-1.x86_64/src/Python-2.7.10',
  'SYSLIBS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TANH_PRESERVES_ZERO_SIGN': 1,
@@ -496,7 +498,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'TCLTK_LIBS': '',
  'TESTOPTS': '-l',
  'TESTPATH': '',
- 'TESTPROG': '/usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9/Lib/test/regrtest.py',
+ 'TESTPROG': '/usr/src/ports/python/python-2.7.10-1.x86_64/src/Python-2.7.10/Lib/test/regrtest.py',
  'TESTPYTHON': './python.exe -Wd -3 -E -tt',
  'TESTPYTHONOPTS': '',
  'THREADOBJ': 'Python/thread.o',
@@ -508,7 +510,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'USE_TOOLBOX_OBJECT_GLUE': 0,
  'VA_LIST_IS_ARRAY': 0,
  'VERSION': '2.7',
- 'VPATH': '/usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9',
+ 'VPATH': '/usr/src/ports/python/python-2.7.10-1.x86_64/src/Python-2.7.10',
  'WANT_SIGFPE_HANDLER': 0,
  'WANT_WCTYPE_FUNCTIONS': 0,
  'WINDOW_HAS_FLAGS': 0,
@@ -522,11 +524,11 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/usr/src/ports/python/python-2.7.9-1.x86_64/build',
- 'abs_srcdir': '/usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9',
+ 'abs_builddir': '/usr/src/ports/python/python-2.7.10-1.x86_64/build',
+ 'abs_srcdir': '/usr/src/ports/python/python-2.7.10-1.x86_64/src/Python-2.7.10',
  'build': 'x86_64-unknown-cygwin',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'host': 'x86_64-unknown-cygwin',
  'prefix': '/usr',
- 'srcdir': '/usr/src/ports/python/python-2.7.9-1.x86_64/src/Python-2.7.9'}
+ 'srcdir': '/usr/src/ports/python/python-2.7.10-1.x86_64/src/Python-2.7.10'}
